from sqlalchemy import Column, Integer, String
from app.database import Base

class {{ class_name }}(Base):
    __tablename__ = "{{ name }}s"

    id = Column(Integer, primary_key=True, index=True)
    name = Column(String, nullable=False, unique=True)
