from pydantic_settings import BaseSettings

class Settings(BaseSettings):
    APP_NAME: str = "{{ project_name }}"
{% if use_db %}
    DATABASE_URL: str = "{{ 'postgresql://user:pass@localhost/db' if db_choice == 'postgres' else 'sqlite:///./app.db' }}"
{% endif %}

    class Config:
        env_file = ".env"

settings = Settings()
